

include "scripts/pages/training/season/calendar.cnc"

// create a subset for the page
func i32x TrainingSeason_CreateDatabaseCopy()
{
	var i32x iSubset,iSendSubset;
	var i32x iIDUserTeam;

	iSubset=Subset_Constructor("SUBSET_TRAINING_SEASON",DATABASE_CLIENT);

	// sets the table that will be send to the server
	Database_AddTables(iSubset,3);
	Table_SetName(iSubset, 0, "DYN_training_season");
	TableSubset_SelectColumns(iSubset, 0, "*");
	Table_SetName(iSubset, 1, "DYN_training_season_week");
	TableSubset_SelectColumns(iSubset, 1, "*");
	Table_SetName(iSubset, 2, "DYN_cyclist");
	TableSubset_SelectColumns(iSubset, 1, "*");

	iIDUserTeam=GetMyTeamId();

	Query_Create(0,iSubset);
	Query_SelectTable(0,"DYN_cyclist");
	Query_SelectWhereIntEqual(0,"DYN_cyclist.fkIDteam",iIDUserTeam);
	Query_Execute(0);
	Query_Create(1,iSubset);
	Query_SelectTable(1,"DYN_training_season");
	Query_SelectWhereIntEqual(1,"DYN_training_season.fkIDcyclist.DYN_cyclist.fkIDteam",iIDUserTeam);
	Query_Execute(1);
	Query_Create(2,iSubset);
	Query_SelectTable(2,"DYN_training_season_week");
	Query_SelectWhereIntEqual(2,"DYN_training_season_week.fkIDtraining_season.DYN_training_season.fkIDcyclist.DYN_cyclist.fkIDteam",iIDUserTeam);
	Query_Execute(2);

	Database_Update(iSubset);

	// a copy is used for managing the data...
	iSendSubset=Database_CopyConstructor("SUBSET_SEND_TRAINING_SEASON", iSubset);

	Subset_Destructor(iSubset);

	return(iSendSubset);
}

func i32x FindTrainingSeasonID(i32x _iPageSubset,i32x _iIDCyclist)
{
	var i32x iQuerySubset;
	var i32x iIDTrainingSeason;

	// creates a subset for the query
	iQuerySubset=Subset_Constructor("SUBSET_SEND_TRAINING_SEASON_QUERY",_iPageSubset);

	Database_AddTables(iQuerySubset,1);
	Table_SetName(iQuerySubset, 0, "DYN_training_season");
	TableSubset_SelectColumns(iQuerySubset, 0, "*");

	// selects the row width fkIDcyclist=_iIDCyclist
	Query_Create(0,iQuerySubset);
	Query_SelectTable(0,"DYN_training_season");
	Query_SelectWhereIntEqual(0,"DYN_training_season.fkIDcyclist",_iIDCyclist);
	Query_Execute(0);

	// checks if the row exists
	if (Table_GetNumRows(iQuerySubset,0)>0)
	{
		// returns the ID of the training season row
		iIDTrainingSeason=Database_GetIntData(iQuerySubset,"DYN_training_season.IDtraining_season",ROW_INDEX,0);
	}
	else
	{
		var i32x iRow;

		// creates a new row
		iRow=Table_AddRow(iQuerySubset,0);

		// puts the corresponding data and gets the ID of the new training season row
		Database_SetIntData(iQuerySubset,"DYN_training_season.fkIDcyclist",ROW_INDEX,iRow,_iIDCyclist);
		iIDTrainingSeason=Database_GetIntData(iQuerySubset,"DYN_training_season.IDtraining_season",ROW_INDEX,iRow);
	}

	Subset_Destructor(iQuerySubset);

	return(iIDTrainingSeason);
}

func i32x FindTrainingSeasonWeekID(i32x _iPageSubset,i32x _iIDTrainingSeason,i32x _iYearWeekIndex)
{
	var i32x iQuerySubset;
	var i32x iIDTrainingSeasonWeek;

	// creates a subset for the query
	iQuerySubset=Subset_Constructor("SUBSET_SEND_TRAINING_SEASON_QUERY",_iPageSubset);

	Database_AddTables(iQuerySubset,1);
	Table_SetName(iQuerySubset, 0, "DYN_training_season_week");
	TableSubset_SelectColumns(iQuerySubset, 0, "*");

	// selects the rows where fkIDtraining_season=_iIDTrainingSeason and gene_i_week=_iYearWeekIndex
	Query_Create(0,iQuerySubset);
	Query_SelectTable(0,"DYN_training_season_week");
	Query_SelectWhereIntEqual(0,"DYN_training_season_week.fkIDtraining_season",_iIDTrainingSeason);
	Query_SelectWhereIntEqual(0,"DYN_training_season_week.gene_i_week",_iYearWeekIndex);
	Query_Execute(0);

	// checks if the row exists
	if (Table_GetNumRows(iQuerySubset,0)>0)
	{
		// returns the ID of the row
		iIDTrainingSeasonWeek=Database_GetIntData(iQuerySubset,"DYN_training_season_week.IDtraining_season_week",ROW_INDEX,0);
	}
	else
	{
		var i32x iRow;

		// creates a new row
		iRow=Table_AddRow(iQuerySubset,0);

		// puts the corresponding data and gets the ID of the row
		Database_SetIntData(iQuerySubset,"DYN_training_season_week.fkIDtraining_season",ROW_INDEX,iRow,_iIDTrainingSeason);
		Database_SetIntData(iQuerySubset,"DYN_training_season_week.gene_i_week",ROW_INDEX,iRow,_iYearWeekIndex);
		iIDTrainingSeasonWeek=Database_GetIntData(iQuerySubset,"DYN_training_season_week.IDtraining_season_week",ROW_INDEX,iRow);
	}

	Subset_Destructor(iQuerySubset);

	return(iIDTrainingSeasonWeek);
}


func void TrainingSeason_AssignTrainingWeekToCyclist(i32x _iPageSubset,i32x _iIDCyclist,i32x _iIDTrainingWeek,i32x _iYearWeekIndex)
{
	var i32x iIDTrainingSeason;
	var i32x iIDTrainingSeasonWeek;

	// looks for the ID of the cyclist in DYN_training_season (creates the row if not available)
	iIDTrainingSeason=FindTrainingSeasonID(_iPageSubset,_iIDCyclist);

	// looks for the row of the cyclist in DYN_training_season_week (or creates it)
	iIDTrainingSeasonWeek=FindTrainingSeasonWeekID(_iPageSubset,iIDTrainingSeason,_iYearWeekIndex);

	// puts the ID week for the training season schedule of the cyclist
	Database_SetIntData(_iPageSubset,"DYN_training_season_week.fkIDtraining_week",ROW_KEY,iIDTrainingSeasonWeek,_iIDTrainingWeek);
}

func i32x TrainingSeason_CreateMonthSelector(Gui_Component _gcPage)
{
	var f32x fCenterAxisX,fSelectorCenterAxisY;
	var Gui_dtPage_TrainingSeason pdtData;
	var i32x iRowHeight;


	fCenterAxisX=385.0*g_fScreenScaleFactor;
	fSelectorCenterAxisY=120.0*g_fScreenScaleFactor;

	pdtData=GetData(_gcPage);

/*	iWidth=40.0*7.0+15.0*6.0+6.0*2;
	iHeight=55.0+12.0;*/

	// display a calendar based on the DYN_day table
	//pdtData.gcCalendar=Calendar_NewCalendar(40.0,55.0,15.0,12.0);
	pdtData.gcCalendar=Calendar_NewCalendar(33.0*g_fScreenScaleFactor,42.0*g_fScreenScaleFactor,11.0*g_fScreenScaleFactor,12.0*g_fScreenScaleFactor);
	MountComponent(_gcPage,pdtData.gcCalendar);
	MoveTo(
		pdtData.gcCalendar,
		(fCenterAxisX-SizeX(pdtData.gcCalendar)/2.0),
		140.0*g_fScreenScaleFactor
	);

	iRowHeight=42.0+12.0;

	// a form that lists all the months and changes the calendar
	pdtData.gcMonthForm=TrainingSeason_MonthForm();
	MountComponent(_gcPage,pdtData.gcMonthForm);
	pdtData.gcMonthForm<<FirstRecord();
	MoveTo(
		pdtData.gcMonthForm,
		(fCenterAxisX-SizeX(pdtData.gcMonthForm)/2.0),
		(fSelectorCenterAxisY-SizeY(pdtData.gcMonthForm)/2.0)
	);

	// - Next month
	pdtData.gcNextMonthButton = NewButtonDyn(smRightButton); 
	MountComponent(_gcPage,pdtData.gcNextMonthButton);
	MoveTo(
		pdtData.gcNextMonthButton,
		(fCenterAxisX+SizeX(pdtData.gcMonthForm)/2.0),
		(fSelectorCenterAxisY-SizeY(pdtData.gcNextMonthButton)/2.0)
	);
	// - Previous month
	pdtData.gcPreviousMonthButton = NewButtonDyn(smLeftButton); 
	MountComponent(_gcPage,pdtData.gcPreviousMonthButton);
	MoveTo(
		pdtData.gcPreviousMonthButton,
		(fCenterAxisX-SizeX(pdtData.gcMonthForm)/2.0-SizeX(pdtData.gcPreviousMonthButton)),
		(fSelectorCenterAxisY-SizeY(pdtData.gcPreviousMonthButton)/2.0)
	);

	return(iRowHeight);
}

func Gui_Component TrainingSeason_CreateHealthEvaluation(i32x _iWidth,i32x _iHeight)
{
	var Gui_Component gcHealthEvaluation,gcCaption;

	gcHealthEvaluation=NewObject(Gui_iComponent_HealthEvaluation);
	StretchTo(gcHealthEvaluation,_iWidth,_iHeight);

	gcCaption=NewCaption(smImpact,"");
	MountComponent(gcHealthEvaluation,gcCaption);
	SetAlign(gcCaption,e_GUI_HAlign_Center,e_GUI_HAlign_Center);
	StretchTo(gcCaption,SizeX(gcHealthEvaluation),SizeY(gcHealthEvaluation));

	return(gcHealthEvaluation);
}

func i32x TrainingSeason_CreateTrainingCyclistSubset(i32x _iTeamID)
{
	var i32x iSubsetIndex;

	// creates a subset that lists all the cyclists of the
	// team of the current player

	iSubsetIndex=Subset_Constructor("SUBSET_CYCLISTS_OF_TEAM",DATABASE_CLIENT);
	Database_AddTables(iSubsetIndex,3);
	Table_SetName(iSubsetIndex, 0, "DYN_cyclist");
	TableSubset_SelectColumns(iSubsetIndex, 0, "*");
	Table_SetName(iSubsetIndex, 1, "DYN_staff");
	TableSubset_SelectColumns(iSubsetIndex, 1, "*");
	TableSubset_SelectAllRows(iSubsetIndex, 1);
	Table_SetName(iSubsetIndex, 2, "DYN_characteristic");
	TableSubset_SelectColumns(iSubsetIndex, 2, "*");
	TableSubset_SelectAllRows(iSubsetIndex, 2);

	Query_Create(0,iSubsetIndex);
	Query_SelectTable(0,"DYN_cyclist");
	Query_SelectWhereIntEqual(0,"DYN_cyclist.fkIDteam",_iTeamID);
	Query_Execute(0);

	return(iSubsetIndex);
}

func void TrainingSeason_OnInitData()
{
	var Gui_Component pthis;
	var Gui_dtPage_TrainingSeason pdtData;
	pthis = GetThis();

	// Set Data pointer
	pdtData = new Gui_dtPage_TrainingSeason;
	pdtData.bFirstLoad = true;
	SetData(pthis,pdtData);
}

func i32x TrainingSeason_OnCreate()
{
	var Gui_Component pthis,pcaption,pbox,window;
	var Gui_dtPage_TrainingSeason pdtData;
	var Gui_Component gcMonthForm;
	var i32x iTeamID;
	var i32x iX,iY,iWidth,iHeight;
	var i32x iRowHeight;

	pthis = GetThis();
	pdtData = GetData(pthis);

	SetComponentNumber(pthis, 20);

	iTeamID=GetMyTeamId();

	// database is created each time the page is shown
	pdtData.iPageSubset=TrainingSeason_CreateDatabaseCopy();

	if (pdtData.bFirstLoad)
	{
		pdtData.iSubsetTrainingCyclist=TrainingSeason_CreateTrainingCyclistSubset(iTeamID);

		iWidth=660.0*g_fScreenScaleFactor;
		iHeight=80.0*g_fScreenScaleFactor;

		pbox=NewBoxFilled(smBlueFrame,iWidth,iHeight);
		MountComponent(pthis,pbox);
		MoveTo(pbox,50.0*g_fScreenScaleFactor,510.0*g_fScreenScaleFactor);

		// cyclists of the team
		pdtData.gcCyclistForm = TrainingSeason_TrainingCyclistForm(pdtData.iSubsetTrainingCyclist);
		MountComponent(pthis,pdtData.gcCyclistForm);
		MoveTo(
			pdtData.gcCyclistForm,
			RelPosX(pbox)+(iWidth-SizeX(pdtData.gcCyclistForm))/2.0,
			RelPosY(pbox)+(iHeight-SizeY(pdtData.gcCyclistForm))/2.0
		);
		pdtData.gcCyclistForm<<FirstRecord();
	}

	// cyclists list of the team
	iX=45.0*g_fScreenScaleFactor;
	iY=110.0*g_fScreenScaleFactor;
	iWidth=160.0*g_fScreenScaleFactor;
	iHeight=385.0*g_fScreenScaleFactor;

	if (pdtData.bFirstLoad)
	{
		pcaption=NewCaption(smBauer,"Cyclists");
		SetScale(pcaption,(800.0/1024.0)*g_fScreenScaleFactor);
		MountComponent(pthis,pcaption);
		MoveTo(pcaption,iX,iY);
		SetAlign(pcaption,e_GUI_HAlign_Center,e_GUI_VAlign_Center);
		StretchTo(pcaption,iWidth,SizeY(pcaption));

		pdtData.gcCaption=pcaption;
	}
	else
	{
		pcaption=pdtData.gcCaption;
	}

	window = NewWindow(iWidth,iHeight-(SizeY(pcaption)+10.0*g_fScreenScaleFactor));
	pdtData.gcCyclistListForm = TrainingSeason_TrainingCyclistListForm(pdtData.iSubsetTrainingCyclist,pdtData.iPageSubset,pdtData.gcCyclistForm);
	window<<WindowMount(pdtData.gcCyclistListForm);
	MountComponent(pthis,window);
	MoveTo(window,iX+(iWidth-SizeX(window))/2.0,iY+SizeY(pcaption)+10.0*g_fScreenScaleFactor);

	pdtData.gcWindow=window;

	pdtData.gcCyclistListForm<<FormRazFilter();
	pdtData.gcCyclistListForm<<RowUncheck();

	iWidth=180.0*g_fScreenScaleFactor;
	iHeight=370.0*g_fScreenScaleFactor;
	iX=665.0*g_fScreenScaleFactor;
	//iY=RelPosY(pdtData.gcCalendar)+SizeY(pdtData.gcCalendar)+6.0-iHeight;
	iY=120.0*g_fScreenScaleFactor;

	if (pdtData.bFirstLoad)
	{
		pbox=NewBoxFilled(smBlueFrame,iWidth,iHeight);
		MountComponent(pthis,pbox);
		MoveTo(pbox,iX-iWidth/2.0,iY);

		pdtData.gcBox=pbox;

		// the calendar and the month form
		pdtData.iScheduleRowHeight=TrainingSeason_CreateMonthSelector(pthis);
	}
	iRowHeight=pdtData.iScheduleRowHeight;

	// the schedule listboxes
	pdtData.gcCyclistSchedule=TrainingSeason_CyclistScheduleList(pdtData.gcCyclistListForm,iRowHeight,pdtData.gcCalendar,pdtData.gcBox,pdtData.iPageSubset);
	MountComponent(pthis,pdtData.gcCyclistSchedule);
	MoveTo(pdtData.gcCyclistSchedule,iX-SizeX(pdtData.gcCyclistSchedule)/2.0,155.0*g_fScreenScaleFactor);

	if (pdtData.bFirstLoad)
	{
		pcaption=NewCaption(smBauer,"Training week");
		SetScale(pcaption,(800.0/1024.0)*g_fScreenScaleFactor);
		SetAlign(pcaption,e_GUI_HAlign_Center,e_GUI_VAlign_Center);
		MountComponent(pthis,pcaption);
		MoveTo(pcaption,iX-SizeX(pcaption)/2.0,RelPosY(pdtData.gcCyclistSchedule)-SizeY(pcaption)-10.0*g_fScreenScaleFactor);

		// Caption
		pcaption = NewCaption(smBauer,"Training Season");
		MountComponent(pthis,pcaption);
		SetColor(pcaption, cPageTitleColor);
		StretchTo(pcaption,g_iScreenWidth,0);
		SetAlign(pcaption,e_GUI_HAlign_Center,e_GUI_VAlign_Top);
		SetScale(pcaption,1.8*g_fScreenScaleFactor);
		MoveTo(pcaption,0,(g_iScreenTopOffset-SizeY(pcaption))/2);

		// some buttons
			// - Back button
		//pdtData.gcBackButton = NewCM2Button(GetLocalizedFromKey(iszOk));
		pdtData.gcBackButton = NewButtonDyn(smBtnCancel);
		MountComponent(pthis,pdtData.gcBackButton);
		MoveTo(pdtData.gcBackButton,g_iScreenWidth-SizeX(pdtData.gcBackButton)-g_iScreenRightOffset,g_iScreenHeight-SizeY(pdtData.gcBackButton)-g_iScreenBottomOffset);

			// - Send button
		//pdtData.gcSendButton = NewCM2Button(GetLocalizedFromKey(iszSend));
		pdtData.gcSendButton = NewButtonDyn(smBtnValid);
		MountComponent(pthis,pdtData.gcSendButton);
		//MoveTo(pdtData.gcSendButton,g_iScreenWidth-SizeX(pdtData.gcSendButton)-20.0*g_fScreenScaleFactor-SizeX(pdtData.gcBackButton)-g_iScreenRightOffset,g_iScreenHeight-SizeY(pdtData.gcBackButton)-g_iScreenBottomOffset);
		MoveTo(pdtData.gcSendButton,g_iScreenWidth-SizeX(pdtData.gcSendButton)-5.0*g_fScreenScaleFactor-SizeX(pdtData.gcBackButton)-g_iScreenRightOffset,g_iScreenHeight-SizeY(pdtData.gcBackButton)-g_iScreenBottomOffset);
	}
	pdtData.gcSendButton<<Hide();

	// Stretch page
	if (pdtData.bFirstLoad)
	{
		StretchTo(pthis,g_iScreenWidth,g_iScreenHeight);
	}

	//pthis<<SelectTrainingMonth(1);
	pdtData.gcMonthForm<<FirstRecord();

	pdtData.bFirstLoad=false;
}

func void TrainingSeason_OnRelease()
{
	var Gui_Component pthis;
	var Gui_dtPage_TrainingSeason pdtData;

	pthis = GetThis();
	pdtData = GetData(pthis);

	DeleteComponent(pdtData.gcCyclistSchedule);
	pdtData.gcCyclistSchedule=NULL;

	DeleteComponent(pdtData.gcWindow);
	pdtData.gcCyclistListForm=NULL;

	Subset_Destructor(pdtData.iPageSubset);
	pdtData.iPageSubset=NULL;
}

func void TrainingSeason_DataChanged()
{
	var Gui_Component pthis;
	var Gui_dtPage_TrainingSeason pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	// the data can be send
	pdtData.gcSendButton<<Show();
}

func i32x  TrainingSeason_OnDestroy()
{
	// uninit page

	var Gui_Component pthis;
	var Gui_dtPage_TrainingSeason pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	// the subset is destroyed
	if (pdtData.iSubsetTrainingCyclist)
	{
		DatabaseSubset_Clear(pdtData.iSubsetTrainingCyclist);
		Subset_Destructor(pdtData.iSubsetTrainingCyclist);
	}
}

func void TrainingSeason_SelectTrainingMonth(i32x _iIDMonth)
{
	var Gui_Component pthis;
	var Gui_dtPage_TrainingSeason pdtData;

	pthis = GetThis();
	pdtData = GetData(pthis);

	pdtData.gcCalendar<<ShowMonth(_iIDMonth);

	pdtData.iIDMonth=_iIDMonth;
	if (pdtData.iIDCyclist && pdtData.gcCyclistSchedule) // if there is a defined cyclist and the schedule component exists!
	{
		// updates the schedule on the calendar
		pdtData.gcCyclistSchedule<<ShowSchedule(pdtData.iIDCyclist,pdtData.iIDMonth);
	}
}

func void TrainingSeason_SelectTrainingCyclist(i32x _iIDCyclist)
{
	var Gui_Component pthis;
	var Gui_dtPage_TrainingSeason pdtData;
	var i32x bBelong;
	var i32x i,iNumRows,iIndex;

	pthis = GetThis();
	pdtData = GetData(pthis);

	pdtData.iIDCyclist=_iIDCyclist;
	if (pdtData.iIDMonth) // if there is a defined month
	{
		// updates the schedule on the calendar
		pdtData.gcCyclistSchedule<<ShowSchedule(pdtData.iIDCyclist,pdtData.iIDMonth);
	}
}


func void  TrainingSeason_OnClick(Gui_Component _pComponent)
{
	var Gui_Component pthis,pback,pparent;
	var Gui_dtPage_TrainingSeason pdtData;

	// get this pointer
	pthis = GetThis();

	// Get Data pointer
	pdtData = GetData(pthis);
	pback = pdtData.gcBackButton;
	if(_pComponent == pback)
	{
		// Click on back button
		pparent = GetParent(pthis);

		// Back
		pparent<<GoBack();
	}
	else if(_pComponent == pdtData.gcSendButton)
	{
		Database_Send(pdtData.iPageSubset,"TrainingSeasonDB",g_pMenuServerSocket);
	}
	else if(_pComponent == pdtData.gcNextMonthButton)
	{
		if (MonthForm_GetMonth(pdtData.gcMonthForm)<12)
		{
			// Go to next month
			pdtData.gcMonthForm<<NextRecord();
		}
	}
	else if(_pComponent == pdtData.gcPreviousMonthButton)
	{
		if (MonthForm_GetMonth(pdtData.gcMonthForm)>1)
		{
			// Go to previous month
			pdtData.gcMonthForm<<PreviousRecord();
		}
	}
}

func Gui_Component TrainingSeason_MonthForm()
{
	var Gui_Component pform;
	var Gui_dtForm_Month pdtData;

	pdtData = new Gui_dtForm_Month;

	pdtData.iJoinMonth=Join_Constructor(DATABASE_CLIENT, "STA_month.IDmonth");

	// creates a new form
	pform = NewForm(DATABASE_CLIENT,"STA_month",false);

	AddInterface(pform,Gui_iForm_Month,pdtData);

	pform<<FormSetWidth(160.0*g_fScreenScaleFactor);
	pform<<FormSetAlign(e_GUI_HAlign_Center, e_GUI_VAlign_Center);
	pform<<FormSetFont(smArial,smBauer);
	pform<<FormSetMaJInform(true);
	// display the name of the nomth...
	pform<<FormShowField("STA_month.gene_strID_name","",0,0);
	pform<<FormSetMaJInform(false);

	return pform;
}

func i32x MonthForm_GetMonth(Gui_Component _gcMonthForm)
{
	var Gui_dtForm_Month	pdtData;

	pdtData=GetData(_gcMonthForm);

	return(pdtData.iMonth);
}

func void MonthForm_ChangeMonthInt(Gui_Component _poField,i32x _iValue,i32x _bChanged)
{
	var Gui_Component		pthis,pparent;
	var Gui_dtForm_Month	pdtData;
	var Gui_dtFormField		pdtField;
	var i32x	iIDMonth;

	pthis=GetThis();
	pdtData=GetData(pthis);
	pdtField=GetData(_poField);
	pparent=GetParent(pthis);

	iIDMonth=Join_GetIntFromIndex(pdtData.iJoinMonth,pdtField.iRow);
	// the selected month has changed: the page gets a message
	pparent<<SelectTrainingMonth(iIDMonth);

	pdtData.iMonth=iIDMonth;
}

func i32x MonthForm_OnDestroy()
{
	var Gui_Component pthis;
	var Gui_dtForm_Month pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	// destroy the join
	Join_Destructor(pdtData.iJoinMonth);
}

func Gui_Component TrainingSeason_TrainingCyclistListForm(i32x _iSubsetIndex,i32x _iPageSubset,Gui_Component _gcCyclistInfo)
{
	var Gui_Component pform;
	var Gui_dtForm_TrainingCyclistList pdtData;

	pdtData = new Gui_dtForm_TrainingCyclistList;
	pdtData.gcCyclistInfo=_gcCyclistInfo;
	pdtData.iPageSubset=_iPageSubset;
	pdtData.iCyclistIDJoin=Join_Constructor(_iSubsetIndex,"DYN_cyclist.IDcyclist");
	pform = NewListForm(_iSubsetIndex,"DYN_cyclist",false);

	AddInterface(pform,Gui_iForm_TrainingCyclistList,pdtData);

	return pform;
}

// returns the last name + first name
func szx TrainingCyclist_FindCompleteName(i32x _iSubsetIndex,i32x _iIDCyclist)
{
	var szx szCyclistName;

	szCyclistName=Database_GetStringData(_iSubsetIndex,"DYN_cyclist.fkIDcharacteristic.DYN_characteristic.civic_sz_firstname", ROW_KEY, _iIDCyclist)+"  ";
	szCyclistName=szCyclistName+Database_GetStringData(_iSubsetIndex,"DYN_cyclist.fkIDcharacteristic.DYN_characteristic.civic_sz_lastname", ROW_KEY, _iIDCyclist);

	return(szCyclistName);
}

// adds the current cyclist to the selection
func void TrainingCyclistListSubForm_Select()
{
	var Gui_Component pthis;
	var Gui_dtForm_TrainingCyslistSubForm pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	pdtData.bSelected=true;

	pthis<<SetBackColor(cTableSelectColor);
}

// removes the current cyclist from the selection
func void TrainingCyclistListSubForm_Unselect()
{
	var Gui_Component pthis;
	var Gui_dtForm_TrainingCyslistSubForm pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	pdtData.bSelected=false;

	pthis<<SetBackColor(pdtData.iOldColor);
}

// toggles the current cyclist
func void TrainingCyclistListSubForm_Toggle()
{
	var Gui_Component pthis;
	var Gui_dtForm_TrainingCyslistSubForm pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	if (pdtData.bSelected)
	{
		TrainingCyclistListSubForm_Unselect();
	}
	else
	{
		TrainingCyclistListSubForm_Select();
	}
}

func void TrainingCyclistListForm_AssignWeekToSelectedCyclists(i32x _iIDWeek,i32x _iWeekIndex)
{
	var Gui_Component pthis,gcSubForm,gcParent;
	var Gui_dtForm_TrainingCyclistList pdtData;
	var Gui_dtForm_TrainingCyslistSubForm pdtSubForm;
	var i32x i,iIDCyclist;
	var i32x iSubFormNumber,iAssignedNumber;

	pthis=GetThis();

	pdtData=GetData(pthis);
	iSubFormNumber=Join_GetNumRows(pdtData.iCyclistIDJoin);

	i=0;
	iAssignedNumber=0;
	while (i<iSubFormNumber)
	{
		gcSubForm=GetComponent(pthis,i);

		var boolx bSelected;
		gcSubForm<<IsSelected(); // just do nothing (else the pdtData is dead)
		pdtSubForm=GetData(gcSubForm);

		if (pdtSubForm.bSelected)
		{
			iIDCyclist=Join_GetIntFromIndex(pdtData.iCyclistIDJoin,i);
			TrainingSeason_AssignTrainingWeekToCyclist(pdtData.iPageSubset,iIDCyclist,_iIDWeek,_iWeekIndex);
			iAssignedNumber=iAssignedNumber+1;
		}

		i=i+1;
	}

	if (iAssignedNumber>0)
	{
		gcParent=GetParent(pthis);
		gcParent<<PageDataChanged();
	}
}

func void TrainingCyclistListForm_GainFocus(Gui_Component _poForm,i32x _iKey)
{
	var Gui_Component pthis;
	var Gui_dtForm_TrainingCyclistList pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	pdtData.gcCyclistInfo<<FormSetRef(ROW_KEY);
	pdtData.gcCyclistInfo<<GoToRecord(_iKey);
	pdtData.gcCyclistInfo<<FormSetRef(ROW_INDEX);
}

func void TrainingCyclistListSubForm_Mouse(i32x _iX,i32x _iY,i32x _iButton)
{
	var Gui_Component pthis,gcParent;

	pthis=GetThis();
	gcParent=GetParent(pthis);

	if (_iButton==0)
	{
		if (GetKeyState(VK_Control))
		{
			pthis<<RowToggle();
		}
		else
		{
			gcParent<<RowUncheck();
			pthis<<RowCheck();
		}
	}
	else if (_iButton==1)
	{
		if (GetKeyState(VK_Control))
		{
			gcParent<<RowToggle();
		}
		else
		{
			gcParent<<RowCheck();
		}
	}
}

func void TrainingCyclistListForm_Select()
{
	var Gui_Component pthis,gcSubForm;
	var Gui_dtForm_TrainingCyclistList pdtData;
	var i32x i,iSubFormNumber;

	pthis=GetThis();

	pdtData=GetData(pthis);
	iSubFormNumber=Join_GetNumRows(pdtData.iCyclistIDJoin);

	i=0;
	while (i<iSubFormNumber)
	{
		gcSubForm=GetComponent(pthis,i);
		gcSubForm<<RowCheck();

		i=i+1;
	}
}

func void TrainingCyclistListForm_Unselect()
{
	var Gui_Component pthis,gcSubForm;
	var Gui_dtForm_TrainingCyclistList pdtData;
	var i32x i,iSubFormNumber;

	pthis=GetThis();

	pdtData=GetData(pthis);
	iSubFormNumber=Join_GetNumRows(pdtData.iCyclistIDJoin);

	i=0;
	while (i<iSubFormNumber)
	{
		gcSubForm=GetComponent(pthis,i);
		gcSubForm<<RowUncheck();

		i=i+1;
	}
}

func void TrainingCyclistListForm_Toggle()
{
	var Gui_Component pthis,gcSubForm;
	var Gui_dtForm_TrainingCyclistList pdtData;
	var i32x i,iSubFormNumber;

	pthis=GetThis();

	pdtData=GetData(pthis);
	iSubFormNumber=Join_GetNumRows(pdtData.iCyclistIDJoin);

	i=0;
	while (i<iSubFormNumber)
	{
		gcSubForm=GetComponent(pthis,i);
		gcSubForm<<RowToggle();

		i=i+1;
	}
}

func void TrainingCyclistListSubForm_IsSelected()
{
	var Gui_Component pthis;
	var Gui_dtForm_TrainingCyslistSubForm pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);
}

func void TrainingCyclistListForm_OnAddForm(Gui_Component _pform,i32x _iIndex)
{
	var Gui_Component pthis,gcNameCaption;
	var Gui_dtForm_TrainingCyslistSubForm pdtSubForm;
	var Gui_dtForm_TrainingCyclistList pdtForm;

	pthis=GetThis();
	pdtForm=GetData(pthis);

	pdtSubForm=new Gui_dtForm_TrainingCyslistSubForm;
	pdtSubForm.bSelected=false;

	_pform<<FormSetWidth(165.0*g_fScreenScaleFactor);
	_pform<<FormSetColor(0);
	_pform<<FormSetTitle(false,false);
	_pform<<FormSetLocked(true);

	_pform<<FormAddVariable("DYN_cyclist.fkIDcharacteristic.DYN_characteristic.civic_sz_firstname","CYCLISTFIRSTNAME");
	_pform<<FormAddVariable("DYN_cyclist.fkIDcharacteristic.DYN_characteristic.civic_sz_lastname","CYCLISTNAME");
	_pform<<FormShowFormatField("DYN_cyclist.IDcyclist",39,"",0,0);

	if (_iIndex%2)
		pdtSubForm.iOldColor=cTableOddRowBackColor;
	else
		pdtSubForm.iOldColor=cTableEvenRowBackColor;
	_pform<<SetBackColor(pdtSubForm.iOldColor);

	AddInterface(_pform,Gui_iForm_TrainingCyslistSubForm,pdtSubForm);
}

func i32x TrainingCyclistListForm_OnDestroy()
{
	var Gui_Component pthis;
	var Gui_dtForm_TrainingCyclistList pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	Join_Destructor(pdtData.iCyclistIDJoin);
}

func Gui_Component TrainingSeason_TrainingCyclistForm(i32x _iSubsetIndex)
{
	var Gui_Component pform,pfield,gcHealthEvaluation;
	var Gui_dtForm_TrainingCyclist pdtData;

	pdtData = new Gui_dtForm_TrainingCyclist;
	pdtData.iSubsetIndex=_iSubsetIndex;
	pdtData.iJoinCyclist=Join_Constructor(pdtData.iSubsetIndex,"DYN_cyclist.IDcyclist");

	pform = NewForm(pdtData.iSubsetIndex,"DYN_cyclist",false);

	AddInterface(pform,Gui_iForm_TrainingCyclist,pdtData);

	// a hidden field to send the cyclist ID when it changes
	pform<<FormSetMaJInform(true);
	pform<<FormShowField("DYN_cyclist.IDcyclist","",0,0);
	pform<<FormSetMaJInform(false);
	pfield=GetLastField(pform);
	pfield<<Hide();

	pdtData.gcCyclistName=NewCaption(smImpact,"");
	SetScale(pdtData.gcCyclistName,1.5);
	pform<<FormAddField(pdtData.gcCyclistName,100,0);

	pdtData.gcTrainerName=NewCaption(smImpact,"");
	SetScale(pdtData.gcTrainerName,1.5);
	pform<<FormAddField(pdtData.gcTrainerName,100,30);

	// the photo of the cyclist
	pform<<FormShowBitmapField("DYN_cyclist.gene_tgaID_photo","",0,0);

	StretchTo(pform,630.0*g_fScreenScaleFactor,SizeY(pform));

	gcHealthEvaluation=TrainingSeason_CreateHealthEvaluation(370.0*g_fScreenScaleFactor,SizeY(pform)*5.0/6.0);
	pform<<FormAddField(gcHealthEvaluation,SizeX(pform)-SizeX(gcHealthEvaluation),(SizeY(pform)-SizeY(gcHealthEvaluation))/2.0);

	return pform;
}

func void TrainingCyclistForm_ChangeCyclist(Gui_Component _poField,i32x _iIDCyclist,i32x _bChanged)
{
	var Gui_Component		pthis,pparent;
	var Gui_dtForm_TrainingCyclist	pdtData;
	var Gui_dtFormField		pdtField;
	var szx					szCyclistName,szTrainerName;
	var i32x				iIDTrainer;

	pthis=GetThis();
	pdtData=GetData(pthis);
	pdtField=GetData(_poField);
	pparent=GetParent(pthis);

	pparent<<SelectTrainingCyclist(_iIDCyclist);

	// puts the lastname + firstname in the same field
	szCyclistName=TrainingCyclist_FindCompleteName(pdtData.iSubsetIndex,_iIDCyclist);
	pdtData.gcCyclistName<<Caption(szCyclistName);

	// fetching the ID of the trainer
	iIDTrainer=Database_GetIntData(DATABASE_CLIENT,"DYN_cyclist.fkIDstaff_trainer",ROW_KEY,_iIDCyclist);
	if (iIDTrainer)
	{
		// puts the lastname + firstname in the same field
		szTrainerName=Database_GetStringData(pdtData.iSubsetIndex,"DYN_staff.fkIDcharacteristic.DYN_characteristic.civic_sz_lastname", ROW_KEY, iIDTrainer)+"  ";
		szTrainerName=szTrainerName+Database_GetStringData(pdtData.iSubsetIndex,"DYN_staff.fkIDcharacteristic.DYN_characteristic.civic_sz_firstname", ROW_KEY, iIDTrainer);
	}
	else
	{
		// if there is no trainer, we put this label
		szTrainerName="self training";
	}
	pdtData.gcTrainerName<<Caption(szTrainerName);
}

func i32x TrainingCyclistForm_OnDestroy()
{
	var Gui_Component		pthis;
	var Gui_dtForm_TrainingCyclist	pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	Join_Destructor(pdtData.iJoinCyclist);
}

func Gui_Component TrainingSeason_CyclistScheduleList(Gui_Component _gcCyclistListForm,i32x _iDeltaY,Gui_Component _gcCalendar,Gui_Component _gcBox,i32x _iPageSubset)
{
	var Gui_Component gcComposite,gcComboBox;
	var Gui_dtComponent_CyclistScheduleList pdtData;
	var i32x i;
	var i32x iIDTeam;
	var i32x iCenterY,iCenterX;
	var i32x iDeltaY;

	gcComposite=NewObject(Gui_iComponent_CyclistScheduleList);
	StretchTo(gcComposite,140.0*g_fScreenScaleFactor,300.0*g_fScreenScaleFactor);

	pdtData=new Gui_dtComponent_CyclistScheduleList;
	pdtData.gcCyclistListForm=_gcCyclistListForm;
	pdtData.gcCalendar=_gcCalendar;
	pdtData.iExtended=false;
	pdtData.bQuiet=false;

	pdtData.gcBox=_gcBox;
	pdtData.iHeightStep=g_fScreenScaleFactor*_iDeltaY;
	pdtData.iBoxWidth=Box_GetWidth(_gcBox);

	pdtData.iQuerySubset=Subset_Constructor("SUBSET_CYCLIST_SCHEDULE",_iPageSubset);
	Database_AddTables(pdtData.iQuerySubset,2);
	Table_SetName(pdtData.iQuerySubset, 0, "DYN_training_season_week");
	TableSubset_SelectColumns(pdtData.iQuerySubset, 0, "*");
	Table_SetName(pdtData.iQuerySubset, 1, "DYN_training_season");
	TableSubset_SelectColumns(pdtData.iQuerySubset, 1, "*");

	pdtData.iTrainingWeekSubset=Subset_Constructor("AVAILABLE_TRAINING_WEEK",DATABASE_CLIENT);
	Database_AddTables(pdtData.iTrainingWeekSubset,1);
	Table_SetName(pdtData.iTrainingWeekSubset,0,"DYN_training_week");
	TableSubset_SelectColumns(pdtData.iTrainingWeekSubset,0,"*");

	iIDTeam=GetMyTeamId();

	Query_Create(0,pdtData.iTrainingWeekSubset);
	Query_SelectTable(0,"DYN_training_week");
	Query_SelectWhereIntEqual(0,"DYN_training_week.fkIDteam",0);
	Query_Execute(0);
	Query_SelectWhereIntEqual(0,"DYN_training_week.fkIDteam",iIDTeam);
	Query_Execute(0);


	pdtData.iStrIDJoin = Join_Constructor(pdtData.iTrainingWeekSubset, "DYN_training_week.gene_sz_displayed_name");
	pdtData.iIDWeekJoin = Join_Constructor(pdtData.iTrainingWeekSubset, "DYN_training_week.IDtraining_week");

	SetData(gcComposite,pdtData);

	iCenterX=SizeX(gcComposite)/2.0;
	iDeltaY=_iDeltaY;
	i=5;
	while (i>=0)
	{
		iCenterY=g_fScreenScaleFactor*(iDeltaY*i+iDeltaY/2.0);

		gcComboBox = NewSelect(smImpact, 130.0*g_fScreenScaleFactor, 100.0*g_fScreenScaleFactor, pdtData.iStrIDJoin, pdtData.iIDWeekJoin);
		MountComponent(gcComposite,gcComboBox);
		MoveTo(gcComboBox,iCenterX-SizeX(gcComboBox)/2.0,iCenterY-SizeY(gcComboBox)/2.0);

		i=i-1;
	}

	return(gcComposite);
}

func i32x CyclistScheduleList_OnDestroy()
{
	var Gui_Component pthis,pComponent;
	var Gui_dtComponent_CyclistScheduleList pdtData;
	var i32x i;

	pthis=GetThis();
	pdtData=GetData(pthis);

	Join_Destructor(pdtData.iIDWeekJoin);
	Join_Destructor(pdtData.iStrIDJoin);

	Subset_Destructor(pdtData.iQuerySubset);
	Subset_Destructor(pdtData.iTrainingWeekSubset);
}

func void CyclistScheduleList_DisplayWeek(i32x _iWeekID,i32x _iYearWeekIndex)
{
	var Gui_Component pthis,gcListBox;
	var Gui_dtComponent_CyclistScheduleList pdtData;
	var i32x iRow;

	pthis=GetThis();
	pdtData=GetData(pthis);

	gcListBox=GetComponent(pthis,_iYearWeekIndex-pdtData.iStartWeek);

	iRow=Join_FindIndexFromIntData(pdtData.iIDWeekJoin,_iWeekID);

	gcListBox<<CellSelect(iRow);
}

func void CyclistScheduleList_ChangeWeek(Gui_Component _pSender,i32x _iValue)
{
	var Gui_Component pthis;
	var Gui_dtComponent_CyclistScheduleList pdtData;
	var i32x i,iFound,iWeekIndex,iWeekColor;

	pthis=GetThis();
	pdtData=GetData(pthis);

	i=0;
	iFound=-1;
	while ((i<6) && (iFound==-1))
	{
		if (_pSender==GetComponent(pthis,i))
			iFound=i;
		i=i+1;
	}

	iWeekIndex=pdtData.iStartWeek+5-iFound;

	if (!pdtData.bQuiet)
	{
		pdtData.gcCyclistListForm<<AssignTrainingWeek(_iValue,iWeekIndex);

		iWeekColor=Database_GetIntData(DATABASE_CLIENT,"DYN_training_week.fkIDcolor.STA_color.gene_i_color",ROW_KEY,_iValue);
		pdtData.gcCalendar<<SelectionColor(iWeekColor);
		pdtData.gcCalendar<<SelectMonthWeek(iWeekIndex-pdtData.iStartWeek+1,true);
	}
}

func void CyclistScheduleList_ToggleSize()
{
	var Gui_Component pthis,gcParent;
	var Gui_dtComponent_CyclistScheduleList pdtData;

	pthis=GetThis();
	pdtData=GetData(pthis);

	if (pdtData.iExtended)
	{
		Stretch(pthis,0,-200);
		pdtData.iExtended=false;
	}
	else
	{
		Stretch(pthis,0,200);
		pdtData.iExtended=true;
	}
}

func void CyclistScheduleList_ResetListBoxCell()
{
	var Gui_Component pthis,gcListBox;
	var Gui_dtComponent_CyclistScheduleList pdtData;
	var i32x i;

	pthis=GetThis();
	pdtData=GetData(pthis);

	i=0;
	while (i<6)
	{
		gcListBox=GetComponent(pthis,i);
		pdtData.bQuiet=true;
		gcListBox<<QuietSelectIndex(pthis,0);
		pdtData.bQuiet=false;
		i=i+1;
	}
}

func void CyclistScheduleList_FindListBoxCell(i32x _iIDWeek,i32x _iWeekIndex)
{
	var Gui_Component pthis,gcListBox;
	var Gui_dtComponent_CyclistScheduleList pdtData;
	var i32x iCellIndex;

	pthis=GetThis();
	pdtData=GetData(pthis);

	iCellIndex=Join_FindIndexFromIntData(pdtData.iIDWeekJoin,_iIDWeek);

	gcListBox=GetComponent(pthis,5-(_iWeekIndex-pdtData.iStartWeek));
	pdtData.bQuiet=true;
	gcListBox<<QuietSelectIndex(pthis,iCellIndex);
	pdtData.bQuiet=false;
}

func void CyclistScheduleList_OnShowSchedule(i32x _iIDCyclist,i32x _iIDMonth)
{
	var Gui_Component pthis,gcListBox;
	var Gui_dtComponent_CyclistScheduleList pdtData;
	var i32x iSubsetIndex,iIDTrainingSeason;
	var i32x i,iNumRows;

	pthis=GetThis();
	pdtData=GetData(pthis);

	pdtData.iIDCyclist=_iIDCyclist;

	// the calendar is updated if the month has changed
	if (pdtData.iLastMonth != _iIDMonth)
	{
		pdtData.iLastMonth = _iIDMonth;

		iSubsetIndex=Subset_Constructor("SUBSET_WEEK_OF_YEAR",DATABASE_CLIENT);
		Database_AddTables(iSubsetIndex,1);
		Table_SetName(iSubsetIndex, 0, "DYN_day");
		TableSubset_SelectColumns(iSubsetIndex, 0, "*");

		// looking for the first and the last week index of the month
		Query_Create(0,iSubsetIndex);
		Query_SelectTable(0,"DYN_day");
		Query_SelectWhereIntEqual(0,"DYN_day.fkIDmonth",_iIDMonth);
		Query_Execute(0);

		pdtData.iStartWeek=Database_GetIntData(iSubsetIndex,"DYN_day.gene_i_year_week",ROW_INDEX,0);
		pdtData.iWeekNumber=Database_GetIntData(iSubsetIndex,"DYN_day.gene_i_year_week",ROW_INDEX,Table_GetNumRows(iSubsetIndex,0)-1)+1-pdtData.iStartWeek;

		pdtData.gcBox<<BoxResize(pdtData.iBoxWidth,35.0*g_fScreenScaleFactor+pdtData.iHeightStep*pdtData.iWeekNumber);

		i=0;
		while (i<pdtData.iWeekNumber)
		{
			gcListBox=GetComponent(pthis,5-i);
			gcListBox<<Show();
			i=i+1;
		}
		while (i<6)
		{
			gcListBox=GetComponent(pthis,5-i);
			gcListBox<<Hide();
			i=i+1;
		}

		Subset_Destructor(iSubsetIndex);
	}

	// looking for the training week of the cyclist between the first and
	// last week of the selected month

	DatabaseSubset_Clear(pdtData.iQuerySubset);

	Query_Create(0,pdtData.iQuerySubset);
	Query_SelectTable(0,"DYN_training_season");
	Query_SelectWhereIntEqual(0,"DYN_training_season.fkIDcyclist",_iIDCyclist);
	Query_Execute(0);

	CyclistScheduleList_ResetListBoxCell();

	i=0;
	while (i<6)
	{
		pdtData.gcCalendar<<SelectMonthWeek(i+1,false);
		i=i+1;
	}
	if (Table_GetNumRows(pdtData.iQuerySubset,1))
	{
		iIDTrainingSeason=Database_GetIntData(pdtData.iQuerySubset,"DYN_training_season.IDtraining_season",ROW_INDEX,0);

		Query_Create(1,pdtData.iQuerySubset);
		Query_SelectTable(1,"DYN_training_season_week");
		Query_SelectWhereIntEqual(1,"DYN_training_season_week.fkIDtraining_season",iIDTrainingSeason);
		Query_SelectWhereIntGreaterThan(1,"DYN_training_season_week.gene_i_week",pdtData.iStartWeek-1);
		Query_SelectWhereIntLessThan(1,"DYN_training_season_week.gene_i_week",pdtData.iStartWeek+pdtData.iWeekNumber);
		Query_Execute(1);

		var i32x iIDWeek,iWeekIndex,iWeekColor;
		i=0;
		iNumRows=Table_GetNumRows(pdtData.iQuerySubset,0);
		while (i<iNumRows)
		{
			iIDWeek=Database_GetIntData(pdtData.iQuerySubset,"DYN_training_season_week.fkIDtraining_week",ROW_INDEX,i);
			iWeekIndex=Database_GetIntData(pdtData.iQuerySubset,"DYN_training_season_week.gene_i_week",ROW_INDEX,i);
			iWeekColor=Database_GetIntData(DATABASE_CLIENT,"DYN_training_week.fkIDcolor.STA_color.gene_i_color",ROW_KEY,iIDWeek);

			pdtData.gcCalendar<<SelectionColor(iWeekColor);
			pdtData.gcCalendar<<SelectMonthWeek(iWeekIndex-pdtData.iStartWeek+1,true);

			CyclistScheduleList_FindListBoxCell(iIDWeek,iWeekIndex);

			i=i+1;
		}
	}
}

