

// return the postfix of the name if the day column in the training week table
func szx GetDayColumnEnd(i32x _iColumnIndex)
{
	var szx szDayNames[7];

	szDayNames[0]="mon";
	szDayNames[1]="tues";
	szDayNames[2]="wednes";
	szDayNames[3]="thurs";
	szDayNames[4]="fri";
	szDayNames[5]="satur";
	szDayNames[6]="sun";

	return(szDayNames[_iColumnIndex]);
}

// displays a week in the week container
func void WeekContainer_DisplayWeek(i32x _iWeekID,i32x _iPageSubset)
{
	var Gui_Component pthis,gcDay,gcCheckBox;
	var Gui_dtComponent_TrainingWeekContainer pdtData;
	var Gui_dtTrainingProgramDay pdtDay;
	var i32x i,j,iProgramCount;
	var i32x iIDDay,iIDprogram;
	var i32x iSubsetIndex;
	var i32x bDietFirst;

	println("reading week "+itoa(_iWeekID));

	pthis=GetThis();
	pdtData=GetData(pthis);

	// creation of a subset used to execute queries (in order to get the programs of the day)
	iSubsetIndex=Subset_Constructor("SUBSET_PROGRAMS_OF_DAY",_iPageSubset);
	Database_AddTables(iSubsetIndex,1);
	Table_SetName(iSubsetIndex,0,"DYN_training_day_program");
	TableSubset_SelectColumns(iSubsetIndex,0,"*");

	// for each day of the week
	i=0;
	while (i<7)
	{
		iIDDay=Database_GetIntData(_iPageSubset,"DYN_training_week.fkIDtraining_day_"+GetDayColumnEnd(i),ROW_KEY,_iWeekID);

		bDietFirst=Database_GetIntData(_iPageSubset,"DYN_training_day.gene_b_1st_program_diet",ROW_KEY,iIDDay);

		// selects all the programs of the day
		DatabaseSubset_Clear(iSubsetIndex);
		Query_Create(0,iSubsetIndex);
		Query_SelectTable(0,"DYN_training_day_program");
		Query_SelectWhereIntEqual(0,"DYN_training_day_program.fkIDtraining_day",iIDDay);
		Query_Execute(0);

		gcDay=GetComponent(pthis,i+pdtData.iDayStartIndex);
		pdtDay=GetData(gcDay);

		gcCheckBox=GetComponent(pthis,i+pdtData.iCheckBoxStartIndex);
		if (bDietFirst)
		{
			gcCheckBox<<QuietCheck();
			pdtDay.bDietFirst=true;
		}
		else
		{
			gcCheckBox<<QuietUncheck();
			pdtDay.bDietFirst=false;
		}

		gcDay<<DayEnable();

		// the old programs of the day are removed
		j=0;
		iProgramCount=pdtDay.iProgramsNumber;
		while (j<iProgramCount)
		{
			gcDay<<RemoveProgram(0);
			j=j+1;
		}

		// for each program of the day
		j=0;
		iProgramCount=Table_GetNumRows(iSubsetIndex,0);
		while (j<iProgramCount)
		{
			// looks for his ID
			iIDprogram=Database_GetIntData(iSubsetIndex,"DYN_training_day_program.fkIDprogram",ROW_INDEX,j);
			// displays it
			gcDay<<AddProgram(iIDprogram);

			j=j+1;
		}

		i=i+1;
	}

	// removes the subset used for queries
	Subset_Destructor(iSubsetIndex);
}

// copy the displayed week in a new one with a new name
func void WeekContainer_CopyWeekAs(i32x _iIDWeek,szx _szWeekName,i32x _iPageSubset)
{
	var i32x iIDNewWeek,iIDDay,iIDTeam;
	var i32x i,iDayIndex,iNewWeekRow;

	iNewWeekRow=Table_AddRow(_iPageSubset,0);
	iIDNewWeek=Database_GetIntData(_iPageSubset,"DYN_training_week.IDtraining_week",ROW_INDEX,iNewWeekRow);

	// puts the ID of the player team
	iIDTeam=GetMyTeamId();
	Database_SetIntData(_iPageSubset,"DYN_training_week.fkIDteam",ROW_INDEX,iNewWeekRow,iIDTeam);
	Database_SetStringData(_iPageSubset,"DYN_training_week.gene_sz_displayed_name",ROW_INDEX,iNewWeekRow,_szWeekName);
	Database_SetStringData(_iPageSubset,"DYN_training_week.gene_sz_name",ROW_INDEX,iNewWeekRow,_szWeekName);

	// creates 7 training days assigned to the new week
	i=0;
	while (i<7)
	{
		iDayIndex=Table_AddRow(_iPageSubset,1);
		iIDDay=Database_GetIntData(_iPageSubset,"DYN_training_day.IDtraining_day",ROW_INDEX,iDayIndex);

		// puts the new day in the week
		Database_SetIntData(_iPageSubset,"DYN_training_week.fkIDtraining_day_"+GetDayColumnEnd(i),ROW_INDEX,iNewWeekRow,iIDDay);

		i=i+1;
	}

	// save the last displayed week in this new one
	WeekContainer_SaveWeek(iIDNewWeek,_iPageSubset);
}

// removes all the programs of a day in the page subset
func void RemoveAllProgramsOfDay(i32x _iSubset,i32x _iIDDay)
{
	var i32x i,iProgramCount;
	var i32x iSubset;

	// create a subset for the query
	iSubset=Subset_Constructor("SUBSET_REMOVE_PROGRAMS",_iSubset);

	Database_AddTables(iSubset,1);
	Table_SetName(iSubset, 0, "DYN_training_day_program");
	TableSubset_SelectColumns(iSubset, 0, "*");

	// selects all the programs of the day
	Query_Create(0,iSubset);
	Query_SelectTable(0,"DYN_training_day_program");
	Query_SelectWhereIntEqual(0,"DYN_training_day_program.fkIDtraining_day",_iIDDay);
	Query_Execute(0);

	// for each found program row
	i=0;
	iProgramCount=Table_GetNumRows(iSubset,0);
	while (i<iProgramCount)
	{
		// remove it from the subset
		Table_DeleteRowFromIndex(iSubset,0,i);
		i=i+1;
	}

	Subset_Destructor(iSubset);
}

// removes a whole training week
func void WeekContainer_RemoveWeek(i32x _iIDWeek,i32x _iPageSubset)
{
	var i32x i,iProgramCount;
	var i32x iIDDay;
	var Gui_dtComponent_TrainingWeekContainer pdtData;
	var Gui_Component pthis;

	pthis=GetThis();
	pdtData=GetData(pthis);

	// for each day
	i=0;
	while (i<7)
	{
		iIDDay=Database_GetIntData(_iPageSubset,"DYN_training_week.fkIDtraining_day_"+GetDayColumnEnd(i),ROW_KEY,_iIDWeek);

		// removes all the programs of the day
		RemoveAllProgramsOfDay(_iPageSubset,iIDDay);
		Database_DeleteNow(_iPageSubset);
		i=i+1;
	}

	// removes the row of the week
	Table_DeleteRowFromKey(_iPageSubset,0,_iIDWeek);

	Database_DeleteNow(_iPageSubset);
}

// saves the displayed week
func void WeekContainer_SaveWeek(i32x _iIDWeek,i32x _iPageSubset)
{
	var i32x i,j,iProgramCount;
	var i32x iNewDayProgramRow;
	var i32x iIDProgram,iIDDay;
	var i32x iJoinProgramID,iJoinDayID;
	var Gui_dtComponent_TrainingWeekContainer pdtData;
	var Gui_dtTrainingProgramDay pdtDay;
	var Gui_dtTrainingProgram pdtProgram;
	var Gui_Component pthis,gcDay,gcProgramDay;

	pthis=GetThis();
	pdtData=GetData(pthis);

	// creates joins to put data in the subset
	iJoinProgramID=Join_Constructor(_iPageSubset,"DYN_training_day_program.fkIDprogram");
	iJoinDayID=Join_Constructor(_iPageSubset,"DYN_training_day_program.fkIDtraining_day");

	// for each day
	i=0;
	while (i<7)
	{
		iIDDay=Database_GetIntData(_iPageSubset,"DYN_training_week.fkIDtraining_day_"+GetDayColumnEnd(i),ROW_KEY,_iIDWeek);

		gcDay=GetComponent(pthis,pdtData.iDayStartIndex+i);
		pdtDay=GetData(gcDay);

		Database_SetIntData(_iPageSubset,"DYN_training_day.gene_b_1st_program_diet",ROW_KEY,iIDDay,pdtDay.bDietFirst);

		// removes all the old programs of the day
		RemoveAllProgramsOfDay(_iPageSubset,iIDDay);
		Database_DeleteNow(_iPageSubset);

		// puts the new displayed programs
		iProgramCount=pdtDay.iProgramsNumber;
		j=0;
		while (j<iProgramCount)
		{
			iNewDayProgramRow=Table_AddRow(_iPageSubset,2);

			// get the program ID
			gcProgramDay=GetComponent(gcDay,pdtDay.iStartIndex+j);
			pdtProgram=GetData(gcProgramDay);
			iIDProgram=pdtProgram.iIDProgram;

			// puts the IDs in the subset
			Join_SetIntFromIndex(iJoinProgramID,iNewDayProgramRow,iIDProgram);
			Join_SetIntFromIndex(iJoinDayID,iNewDayProgramRow,iIDDay);

			j=j+1;
		}

		i=i+1;
	}

	// removes the joins used for putting data
	Join_Destructor(iJoinProgramID);
	Join_Destructor(iJoinDayID);
}
